<?php
/**
 * Initialize the options before anything else.
 */
add_action( 'admin_init', 'custom_theme_options', 1 );

/**
 * Build the custom settings & update OptionTree.
 */
function custom_theme_options() {
  /**
   * Get a copy of the saved settings array. 
   */
  $saved_settings = get_option( 'option_tree_settings', array() );
  
  /**
   * Custom settings array that will eventually be 
   * passes to the OptionTree Settings API Class.
   */
  $custom_settings = array( 
		'contextual_help' => array( 
		'sidebar'       => ''
    ),
    'sections'        => array( 
      array(
			'id'          => 'general',
			'title'       => 'همگانی'
      ),
      array(
			'id'          => 'header',
			'title'       => 'سربرگ'
      ),
      array(
			'id'          => 'menu',
			'title'       => 'فهرست'
      ),
      array(
			'id'          => 'slider',
			'title'       => 'اسلایدر'
      ),
      array(
			'id'          => 'fix_post',
			'title'       => 'پست ثابت'
      ),
      array(
			'id'          => 'footer',
			'title'       => 'پاورقی'
      ),
      array(
			'id'          => 'banner_ads',
			'title'       => 'تبلیغات'
      ),
      array(
			'id'          => 'social',
			'title'       => 'شبکه‌های اجتماعی'
      ),
      array(
			'id'          => 'css_js',
			'title'       => 'Css / Js'
      )
    ),
    'settings'        => array( 
      array(
			'id'          => 'short_description',
			'label'       => 'توضیح کوتاه درباره‌ی سایت',
			'desc'        => 'توضیحی کوتاه که در سربرگ پوسته نمایش داده می‌شود.',
			'std'         => 'دانلود رایگان نرم افزار',
			'type'        => 'text',
			'section'     => 'general'
      ),
      array(
			'id'          => 'favicon',
			'label'       => 'فاویکون',
			'desc'        => 'پیشنهاد می‌شود اندازه‌ی فاویکون 16px × 16px باشد.',
			'std'         => get_stylesheet_directory_uri().'/images/favicon.ico',
			'type'        => 'upload',
			'section'     => 'general'
      ),
	  array(
            'id'      => 'feed_uri',
            'label'   => 'شناسه فیدبرنر',
            'desc'    => 'شناسه نشانی فیدبرنر خود را وارد کنید',
            'std'     => '',
			'section' => 'general',
            'type'    => 'text',
            'class'   => '',
            'choices' => array()
      ),
	  array(
            'id'      => 'report_page',
            'label'   => 'گزارش لینک خراب',
            'desc'    => 'برگه گزارش لینک خراب را انتخاب کنید',
			'section' => 'general',
            'type'    => 'page-select',
            'choices' => array()
      ),

// Header
      array(
			'id'          => 'logo_image',
			'label'       => 'لوگوی سربرگ',
			'desc'        => 'پیشنهاد می‌شود اندازه‌ی لوگو 312px × 75px باشد.',
			'std'         => get_stylesheet_directory_uri().'/images/logo.png',
			'type'        => 'upload',
			'section'     => 'header'
      ),
      array(
			'id'          => 'email',
			'label'       => 'نشانی رایانامه',
			'desc'        => 'نشانی ایمیل خود را وارد نمایید.',
			'type'        => 'text',
			'section'     => 'header'
      ),
      array(
			'id'          => 'tel',
			'label'       => 'شماره تلفن',
			'desc'        => 'شماره تلفن خود را وارد نمایید.',
			'type'        => 'text',
			'section'     => 'header'
      ),

// Menu
	  array(
            'id'      => 'software',
            'label'   => 'نرم افزار',
            'desc'    => 'دسته‌بندی نرم افزار را انتخاب کنید',
			'section' => 'menu',
            'type'    => 'category-select',
            'choices' => array()
      ),
	  array(
            'id'      => 'game',
            'label'   => 'بازی',
            'desc'    => 'دسته‌بندی بازی را انتخاب کنید',
			'section' => 'menu',
            'type'    => 'category-select',
            'choices' => array()
      ),
	  array(
            'id'      => 'android',
            'label'   => 'اندروید',
            'desc'    => 'دسته‌بندی اندروید را انتخاب کنید',
			'section' => 'menu',
            'type'    => 'category-select',
            'choices' => array()
      ),
	  array(
            'id'      => 'music',
            'label'   => 'موسیقی',
            'desc'    => 'دسته‌بندی موسیقی را انتخاب کنید',
			'section' => 'menu',
            'type'    => 'category-select',
            'choices' => array()
      ),
	  array(
            'id'      => 'film',
            'label'   => 'فیلم',
            'desc'    => 'دسته‌بندی فیلم را انتخاب کنید',
			'section' => 'menu',
            'type'    => 'category-select',
            'choices' => array()
      ),
	  array(
            'id'      => 'contact_page',
            'label'   => 'تماس با ما',
            'desc'    => 'برگه تماس را انتخاب کنید',
			'section' => 'menu',
            'type'    => 'page-select',
            'choices' => array()
      ),

// Slider
	  array(
            'id'      => 'slider_on_off',
            'label'   => 'فعال کردن اسلایدر',
            'desc'    => 'نمایش یا پنهان کردن اسلایدر را مشخص سازید',
            'std'     => 'off',
            'type'    => 'on-off',
			'section'     => 'slider',
            'choices' => array()
      ),
	  array(
            'id'      => 'slide_speed',
            'label'   => 'سرعت حرکت',
            'desc'    => 'سرعت چرخش اسلایدر را وارد کنید',
            'std'     => '4500',
            'type'    => 'text',
			'section'     => 'slider',
            'choices' => array()
      ),
	  array(
			'id'          => 'slider_list',
			'label'       => 'اسلایدها',
			'desc'        => 'فهرست اسلایدهای شما در خانه ( پیشنهاد : 3 تا 6 اسلاید )',
			'type'        => 'list-item',
			'section'     => 'slider',
			'choices'     => array(),
			'settings'    => array(
	  array(
            'id'      => 'title_second',
            'label'   => 'زیر عنوان',
            'desc'    => 'زیر عنوان را وارد نمایید',
            'type'    => 'text',
            'choices' => array()
      ),
	  array(
            'id'      => 'slider_image',
            'label'   => 'تصویر بنر',
            'desc'    => 'پیشنهاد می‌شود اندازه‌ی تصویر 1170px × 350px باشد.',
            'type'    => 'upload',
            'choices' => array()
      ),
      array(
            'id'      => 'slider_url',
            'label'   => 'پیوند بنر',
            'desc'    => 'نشانی را با //:http وارد نمایید.',
            'std'     => '#',
            'type'    => 'text',
            'choices' => array()
          )
        )
      ),

// Fix Post
	  array(
            'id'      => 'fix_post_on_off',
            'label'   => 'فعال کردن پست ثابت',
            'desc'    => 'نمایش یا پنهان کردن پست ثابت را مشخص سازید',
            'std'     => 'off',
            'type'    => 'on-off',
			'section'     => 'fix_post',
            'choices' => array()
      ),
      array(
			'id'          => 'fix_post_title',
			'label'       => 'عنوان',
			'desc'        => 'عنوان پست ثابت را وارد نمایید',
			'std'         => 'عنوان آزمایشی پست ثابت',
			'type'        => 'text',
			'section'     => 'fix_post'
      ),
      array(
			'id'          => 'fix_post_image',
			'label'       => 'تصویر',
			'desc'        => 'پیشنهاد می‌شود از اندازه‌ی پیش‌فرض استفاده شود',
			'std'         => get_stylesheet_directory_uri().'/images/xiaomi.png',
			'type'        => 'upload',
			'section'     => 'fix_post'
      ),
      array(
			'id'          => 'fix_post_text',
			'label'       => 'محتوای متنی',
			'desc'        => 'محتوای متنی پست ثابت را وارد نمایید',
			'std'         => 'لورم ایپسوم یا طرح‌نما به متنی آزمایشی و بی‌معنی در صنعت چاپ، صفحه‌آرایی و طراحی گرافیک گفته می‌شود. طراح گرافیک از این متن به عنوان عنصری از ترکیب‌بندی برای پرکردن صفحه و ارایه اولیه شکل ظاهری و کلی طرح سفارش گرفته شده استفاده می‌نماید.',
			'type'        => 'textarea',
			'section'     => 'fix_post'
      ),
      array(
			'id'          => 'fix_post_button_text',
			'label'       => 'متن دکمه‌ی اول',
			'desc'        => 'متن دکمه‌ی اول را وارد نمایید',
			'std'         => 'توضیحات',
			'type'        => 'text',
			'section'     => 'fix_post'
      ),
      array(
			'id'          => 'fix_post_button_text_url',
			'label'       => 'پیوند دکمه‌ی اول',
			'desc'        => 'پیوند دکمه‌ی اول را وارد نمایید',
			'std'         => '#',
			'type'        => 'text',
			'section'     => 'fix_post'
      ),
      array(
			'id'          => 'fix_post_button_text_2',
			'label'       => 'متن دکمه‌ی دوم',
			'desc'        => 'متن دکمه‌ی دوم را وارد نمایید',
			'std'         => 'خرید آنلاین',
			'type'        => 'text',
			'section'     => 'fix_post'
      ),
      array(
			'id'          => 'fix_post_button_text_url_2',
			'label'       => 'پیوند دکمه‌ی دوم',
			'desc'        => 'پیوند دکمه‌ی دوم را وارد نمایید',
			'std'         => '#',
			'type'        => 'text',
			'section'     => 'fix_post'
      ),

// Footer
      array(
			'id'          => 'footer_logo_image',
			'label'       => 'لوگوی پاورقی',
			'desc'        => 'پیشنهاد می‌شود اندازه‌ی لوگو 75px × 75px باشد.',
			'std'         => get_stylesheet_directory_uri().'/images/footer-logo.png',
			'type'        => 'upload',
			'section'     => 'footer'
      ),
      array(
			'id'          => 'copyright',
			'label'       => 'متن کپی رایت',
			'desc'        => 'متن کپی رایت را وارد نمایید.',
			'type'        => 'text',
			'section'     => 'footer'
      ),
	  array(
            'id'      => 'about',
            'label'   => 'درباره',
            'desc'    => 'درباره‌ی سایت خود بنویسید، این متن در پاورقی استفاده خواهد شد.',
            'std'     => 'این متن را می‌توانید از مسیر: پیشخوان > نمایش > تنظیمات پوسته > برگ پاورقی، تغییر دهید.',
			'section' => 'footer',
            'type'    => 'textarea',
            'choices' => array()
      ),

// Text Ads
	  array(
			'id'          => 'text_ads_list',
			'label'       => 'تبلیغات متنی',
			'desc'        => 'فهرست تبلیغات متنی شما در نوارکناری راست',
			'type'        => 'list-item',
			'section'     => 'banner_ads',
			'choices'     => array(),
			'settings'    => array(
	  array(
            'id'      => 'text_ads_url',
            'label'   => 'پیوند تبلیغ',
            'desc'    => 'نشانی را با //:http وارد نمایید.',
            'std'     => '#',
            'type'    => 'text',
            'choices' => array()
          )
        )
      ),

// Banner Ads
	  array(
			'id'          => 'banner_ads_list',
			'label'       => 'تبلیغات زیر اسلایدر',
			'desc'        => 'فهرست تبلیغات بنری شما در زیر اسلایدر ( پیشنهاد : 4 بنر )',
			'type'        => 'list-item',
			'section'     => 'banner_ads',
			'choices'     => array(),
			'settings'    => array(
	  array(
            'id'      => 'banner_image',
            'label'   => 'تصویر بنر',
            'desc'    => 'پیشنهاد می‌شود اندازه‌ی بنر 468px × 60px باشد.',
            'std'     => get_stylesheet_directory_uri().'/images/ads-468.jpg',
            'type'    => 'upload',
            'choices' => array()
      ),
      array(
            'id'      => 'banner_url',
            'label'   => 'پیوند بنر',
            'desc'    => 'نشانی را با //:http وارد نمایید.',
            'std'     => '#',
            'type'    => 'text',
            'choices' => array()
          )
        )
      ),

	  array(
			'id'          => 'banner_right_ads_list',
			'label'       => 'تبلیغات نوارکناری راست',
			'desc'        => 'فهرست تبلیغات بنری شما در نوارکناری ( پیشنهاد : 2 تا 3 بنر )',
			'type'        => 'list-item',
			'section'     => 'banner_ads',
			'choices'     => array(),
			'settings'    => array(
	  array(
            'id'      => 'banner_right_image',
            'label'   => 'تصویر بنر',
            'desc'    => 'پیشنهاد می‌شود اندازه‌ی بنر 270px × 203px باشد.',
            'std'     => get_stylesheet_directory_uri().'/images/ads-right5.jpg',
            'type'    => 'upload',
            'choices' => array()
      ),
      array(
            'id'      => 'banner_right_url',
            'label'   => 'پیوند بنر',
            'desc'    => 'نشانی را با //:http وارد نمایید.',
            'std'     => '#',
            'type'    => 'text',
            'choices' => array()
          )
        )
      ),

	  array(
			'id'          => 'banner_left_ads_list',
			'label'       => 'تبلیغات نوارکناری چپ',
			'desc'        => 'فهرست تبلیغات بنری شما در نوارکناری ( پیشنهاد : 2 تا 4 بنر )',
			'type'        => 'list-item',
			'section'     => 'banner_ads',
			'choices'     => array(),
			'settings'    => array(
	  array(
            'id'      => 'banner_left_image',
            'label'   => 'تصویر بنر',
            'desc'    => 'پیشنهاد می‌شود اندازه‌ی بنر 120px × 240px باشد.',
            'std'     => get_stylesheet_directory_uri().'/images/sams.jpg',
            'type'    => 'upload',
            'choices' => array()
      ),
      array(
            'id'      => 'banner_left_url',
            'label'   => 'پیوند بنر',
            'desc'    => 'نشانی را با //:http وارد نمایید.',
            'std'     => '#',
            'type'    => 'text',
            'choices' => array()
          )
        )
      ),

// Social
      array(
			'id'          => 'social_rss',
			'label'       => 'نشانی خوراک - RSS',
			'desc'        => 'نشانی خوراک سایت خود را وارد نمایید.',
			'type'        => 'text',
			'section'     => 'social'
      ),
      array(
			'id'          => 'social_twitter',
			'label'       => 'تویتر',
			'desc'        => 'نشانی برگه‌ی تویتر خود را وارد نمایید.',
			'type'        => 'text',
			'section'     => 'social'
      ),
      array(
			'id'          => 'social_gplus',
			'label'       => 'گوگل پلاس',
			'desc'        => 'نشانی برگه‌ی گوگل پلاس خود را وارد نمایید.',
			'type'        => 'text',
			'section'     => 'social'
      ),
      array(
			'id'          => 'social_facebook',
			'label'       => 'فیسبوک',
			'desc'        => 'نشانی برگه‌ی فیسبوک خود را وارد نمایید.',
			'type'        => 'text',
			'section'     => 'social'
      ),
      array(
			'id'          => 'social_instagram',
			'label'       => 'اینستاگرام',
			'desc'        => 'نشانی برگه‌ی اینستاگرام خود را وارد نمایید.',
			'type'        => 'text',
			'section'     => 'social'
      ),

// Css and Js
      array(
			'id'          => 'css_customize',
			'label'       => 'سفارشی کردن سی اس اس',
			'desc'        => 'شخصی سازی‌های خود را در اینجا قرار دهید',
			'type'        => 'css',
			'section'     => 'css_js'
      ),
      array(
			'id'          => 'js_customize',
			'label'       => 'سفارشی کردن جاوا اسکریپت',
			'desc'        => 'شخصی سازی‌های خود را در اینجا قرار دهید',
			'type'        => 'javascript',
			'section'     => 'css_js'
      )
	)
  );
  
  /* allow settings to be filtered before saving */
  $custom_settings = apply_filters( 'option_tree_settings_args', $custom_settings );
  
  /* settings are not the same update the DB */
  if ( $saved_settings !== $custom_settings ) {
    update_option( 'option_tree_settings', $custom_settings ); 
  }
  
}